@@ -213,7 +213,8 @@ class ExternalDownload(ExternalStorage):
         # url = url.replace("192.168.220.19", "localhost")
         context = (
             open(target_path, "wb")
-            if isinstance(target_path, str) or isinstance(target_path, pathlib.PosixPath)
+            if isinstance(target_path, str)
+            or isinstance(target_path, pathlib.PosixPath)
             else nullcontext(target_path)
         )
         with urllib.request.urlopen(url) as response, context as out_file:
@@ -589,7 +590,8 @@ class Firecrest:
         self._json_response([resp], 200)
         context = (
             open(target_path, "wb")
-            if isinstance(target_path, str) or isinstance(target_path, pathlib.PosixPath)
+            if isinstance(target_path, str)
+            or isinstance(target_path, pathlib.PosixPath)
             else nullcontext(target_path)
         )
         with context as f:
@@ -617,7 +619,8 @@ class Firecrest:
         }
         context = (
             open(source_path, "rb")
-            if isinstance(source_path, str) or isinstance(source_path, pathlib.PosixPath)
+            if isinstance(source_path, str)
+            or isinstance(source_path, pathlib.PosixPath)
             else nullcontext(source_path)
         )
         with context as f:
